/*
 * file CcVobTag.java
 * 
 * Licensed Materials - Property of IBM
 * Restricted Materials of IBM 
 *
 * com.ibm.rational.wvcm.stp.cc.CcVobTag
 *
 * (C) Copyright IBM Corporation 2008.  All Rights Reserved.
 * Note to U.S. Government Users Restricted Rights:  Use, duplication or 
 * disclosure restricted by GSA ADP  Schedule Contract with IBM Corp.
 */

package com.ibm.rational.wvcm.stp.cc;

import static com.ibm.rational.wvcm.stpex.StpExBase.PROPERTY_NAMESPACE;

import javax.wvcm.WvcmException;
import javax.wvcm.PropertyNameList.PropertyName;

import com.ibm.rational.wvcm.stpex.StpExBase;

/**
 * <p>
 * A proxy for a ClearCase VOB tag - the handle by which a ClearCase VOB
 * is identified and managed.
 * </p>
 * <p>
 * VOB tags are treated as distinct objects from VOBs in order to allow for 
 * the retrieval of basic VOB info and passing of handles to VOBs without
 * incurring the overhead of actually opening a real VOB connection.
 * </p>
 */

public interface CcVobTag extends CcResource {

    /** Global path for this VOB's storage */
    PropertyName<String> GLOBAL_PATH =
        new PropertyName<String>(PROPERTY_NAMESPACE, "global-path");
    
    /**
     * Returns the value of this proxy's {@link #GLOBAL_PATH} property.
     * 
     * @return global pathname for this VOB's storage 
     * @throws WvcmException
     *             if this proxy doesn't define a value for this property.
     */
    public String getGlobalPath() throws WvcmException;

    /** Name of host on which the VOB resides */
    PropertyName<String> HOST_NAME =
        new PropertyName<String>(PROPERTY_NAMESPACE, "host-name");
    
    /**
     * Returns the value of this proxy's {@link #HOST_NAME} property.
     * 
     * @return host name for this VOB
     * @throws WvcmException
     *             if this proxy doesn't define a value for this property.
     */
    public String getHostName() throws WvcmException;

    /** Host specific path for this VOB's storage */
    PropertyName<String> HOST_PATH =
        new PropertyName<String>(PROPERTY_NAMESPACE, "host-path");

    /**
     * Returns the value of this proxy's {@link #HOST_PATH} property.
     * 
     * @return host specific pathname for this VOB's storage 
     * @throws WvcmException
     *             if this proxy doesn't define a value for this property.
     */
    public String getHostPath() throws WvcmException;

    /** Is this a tag for a project VOB? */
    PropertyName<Boolean> IS_PROJECT_VOB =
        new PropertyName<Boolean>(PROPERTY_NAMESPACE, "is-project-vob");

    /**
     * Returns the value of this proxy's {@link #IS_PROJECT_VOB} property.
     * 
     * @return true if the VOB tag is for a project VOB, else false
     * @throws WvcmException
     *             if this proxy doesn't define a value for this property.
     */
    boolean getIsProjectVob() throws WvcmException;

    /** Is this a tag for a public VOB? */
    PropertyName<Boolean> IS_PUBLIC =
        new PropertyName<Boolean>(PROPERTY_NAMESPACE, "is-public");

    /**
     * Returns the value of this proxy's {@link #IS_PUBLIC} property.
     * 
     * @return true if the VOB tag is for a publicVOB, else false
     * @throws WvcmException
     *             if this proxy doesn't define a value for this property.
     */
    boolean getIsPublic() throws WvcmException;

    /** 
     * Mount options specified for this VOB tag in the registry.
     */
    PropertyName<String> MOUNT_OPTIONS =
        new PropertyName<String>(PROPERTY_NAMESPACE, "mount-options");

    /**
     * Returns the value of this proxy's {@link #MOUNT_OPTIONS} property.
     * 
     * @return string of mount options, null if none were specified.
     * @throws WvcmException
     *             if this proxy doesn't define a value for this property.
     */
    String getMountOptions() throws WvcmException;

    /** The VOB to which this tag refers */
    PropertyName<CcVob> VOB =
        new PropertyName<CcVob>(PROPERTY_NAMESPACE, "vob");

    /**
     * Returns the value of this proxy's {@link #VOB} property.
     * 
     * @return the VOB to which this tag refers, as a CcVob instance
     * @throws WvcmException
     *             if this proxy doesn't define a value for this property.
     */
    CcVob getVob() throws WvcmException;
    
    /** The registry region this tag resides in */
    PropertyName<CcRegistryRegion> REGISTRY_REGION =
        new PropertyName<CcRegistryRegion>(PROPERTY_NAMESPACE, "vobtag-registry-region");
    
    /**
     * Returns the value of this proxy's {@link #REGISTRY_REGION} property.
     * 
     * @return A proxy for the registry region of this VOB tag.
     * @throws WvcmException 
     *             if this proxy doesn't define a value for this property.
     */
    CcRegistryRegion getRegistryRegion() throws WvcmException;
}
